@@ -5,10 +5,12 @@
 #include "TimeFunctions.h"
 #include "GlobalVariables.h"
 
-void exitWithError(string messageOut, ostream &streamOut1, ostream &streamOut2, int errorInt, Parameters &P) {
+void exitWithError(string messageOut, ostream &streamOut1, ostream &streamOut2, int errorInt, Parameters &P)
+{
+    if (P.runThreadN>1) 
+        pthread_mutex_lock(&g_threadChunks.mutexError);
     time_t timeCurrent;
     time( &timeCurrent);
-    if (P.runThreadN>1) pthread_mutex_lock(&g_threadChunks.mutexError);
     if (streamOut1.good()) {
         streamOut1 << "\n" << messageOut << endl << timeMonthDayTime(timeCurrent) <<" ...... FATAL ERROR, exiting\n"  <<flush;
     };
@@ -20,14 +22,16 @@ void exitWithError(string messageOut, ostream &streamOut1, ostream &streamOut2,
     exit(errorInt);
 };
 
-void warningMessage(string messageOut, ostream &streamOut1, ostream &streamOut2, Parameters &P) {
-    time_t timeCurrent;
-    time( &timeCurrent);
-    if (P.runThreadN>1) pthread_mutex_lock(&g_threadChunks.mutexError);
+void warningMessage(string messageOut, ostream &streamOut1, ostream &streamOut2, Parameters &P)
+{
+    if (P.runThreadN>1) 
+        pthread_mutex_lock(&g_threadChunks.mutexError);
     if (streamOut1.good()) {
-        streamOut1 << "WARNING: " << messageOut << " : " << timeMonthDayTime(timeCurrent) <<endl;
+        streamOut1 << "!!!!! WARNING: " << messageOut <<endl;
     };
     if (streamOut2.good()) {
-        streamOut2 << "WARNING: " << messageOut << "\t\t " << timeMonthDayTime(timeCurrent) <<endl;
+        streamOut2 << "!!!!! WARNING: " << messageOut <<endl;
     };
-};
\ No newline at end of file
+    if (P.runThreadN>1) 
+        pthread_mutex_unlock(&g_threadChunks.mutexError);    
+};
