@@ -261,7 +261,7 @@ Parameters::Parameters() {//initalize parameters info
     //quant
     parArray.push_back(new ParameterInfoVector <string> (-1, -1, "quantMode", &quant.mode));
     parArray.push_back(new ParameterInfoScalar <int>     (-1, -1, "quantTranscriptomeBAMcompression", &quant.trSAM.bamCompression));
-    parArray.push_back(new ParameterInfoScalar <string>     (-1, -1, "quantTranscriptomeBan", &quant.trSAM.ban));
+    parArray.push_back(new ParameterInfoScalar <string>     (-1, -1, "quantTranscriptomeSAMoutput", &quant.trSAM.output));
 
     //2-pass
     parArray.push_back(new ParameterInfoScalar <uint>   (-1, -1, "twopass1readsN", &twoPass.pass1readsN));
@@ -297,6 +297,7 @@ Parameters::Parameters() {//initalize parameters info
     parArray.push_back(new ParameterInfoVector <string>   (-1, -1, "soloInputSAMattrBarcodeSeq",&pSolo.samAtrrBarcodeSeq));
     parArray.push_back(new ParameterInfoVector <string>   (-1, -1, "soloInputSAMattrBarcodeQual",&pSolo.samAtrrBarcodeQual));
     parArray.push_back(new ParameterInfoScalar <string>   (-1, -1, "soloCellReadStats",&pSolo.readStats.type));
+    parArray.push_back(new ParameterInfoScalar <string>   (-1, -1, "soloCBtype",&pSolo.CBtype.typeString));
 
     parameterInputName.push_back("Default");
     parameterInputName.push_back("Command-Line-Initial");
@@ -862,6 +863,7 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
     if (wasp.outputMode=="SAMtag") {
         wasp.yes=true;
         wasp.SAMtag=true;
+        var.heteroOnly=true;
     } else if (wasp.outputMode=="None") {
         //nothing to do
     } else {
@@ -910,14 +912,18 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
                     };
                     inOut->outQuantBAMfile=bgzf_open(outQuantBAMfileName.c_str(),("w"+to_string((long long) quant.trSAM.bamCompression)).c_str());
                 };
-                if (quant.trSAM.ban=="IndelSoftclipSingleend") {
+                if (quant.trSAM.output=="BanSingleEnd_BanIndels_ExtendSoftclip") {
                     quant.trSAM.indel=false;
                     quant.trSAM.softClip=false;
                     quant.trSAM.singleEnd=false;
-                } else if (quant.trSAM.ban=="Singleend") {
+                } else if (quant.trSAM.output=="BanSingleEnd") {
                     quant.trSAM.indel=true;
                     quant.trSAM.softClip=true;
                     quant.trSAM.singleEnd=false;
+                } else if (quant.trSAM.output=="BanSingleEnd_ExtendSoftclip") {
+                    quant.trSAM.indel=true;
+                    quant.trSAM.softClip=false;
+                    quant.trSAM.singleEnd=false;
                 };
             } else if  (quant.mode.at(ii)=="GeneCounts") {
                 quant.geCount.yes=true;
