@@ -166,7 +166,7 @@ class Parameters {
 
         int outSAMtlen;
 
-        struct {bool NH,HI,AS,NM,MD,nM,jM,jI,RG,XS,rB,vG,vA,vW,ha,ch,MC,CR,CY,UR,UY,CB,UB,GX,GN,gx,gn,sM,sS,sQ,cN;} outSAMattrPresent, outSAMattrPresentQuant;
+        struct {bool NH,HI,AS,NM,MD,nM,jM,jI,RG,XS,rB,vG,vA,vW,ha,ch,MC,CR,CY,UR,UY,CB,UB,GX,GN,gx,gn,sM,sS,sQ,cN,sF;} outSAMattrPresent, outSAMattrPresentQuant;
 
         vector <int> outSAMattrOrder, outSAMattrOrderQuant;
         int outBAMcompression;
@@ -301,7 +301,7 @@ class Parameters {
                 bool softClip;
                 bool singleEnd;
                 int bamCompression;
-                string ban;
+                string output;
             } trSAM;
 
             struct {
@@ -330,6 +330,7 @@ class Parameters {
         //variation parameters
         struct {
             bool yes=false;
+            bool heteroOnly=false;
             string vcfFile;
         } var;
 
