@@ -1,7 +1,7 @@
 #include "SoloReadBarcode.h"
 #include "streamFuns.h"
 
-SoloReadBarcode::SoloReadBarcode(Parameters &Pin) : P(Pin), pSolo(P.pSolo)
+SoloReadBarcode::SoloReadBarcode(Parameters &P) : P(P), pSolo(P.pSolo)
 {
     if (pSolo.type==0)
         return;
@@ -10,10 +10,7 @@ SoloReadBarcode::SoloReadBarcode(Parameters &Pin) : P(Pin), pSolo(P.pSolo)
         stats.V[ii]=0;
 
     if (pSolo.cbWLyes) {
-        cbReadCountExact = new uint32[pSolo.cbWLsize];
-        for (uint32 ii=0; ii<pSolo.cbWLsize; ii++) {
-            cbReadCountExact[ii]=0;
-        };
+        cbReadCountExact.resize(pSolo.cbWLsize,0);
     };
 
     for (uint32 jj=0;jj<4;jj++) {
@@ -22,6 +19,8 @@ SoloReadBarcode::SoloReadBarcode(Parameters &Pin) : P(Pin), pSolo(P.pSolo)
             homoPolymer[jj]=(homoPolymer[jj]<<2)+jj;
         };
     };
+    
+    qualHist.fill(0);
 };
 
 void SoloReadBarcode::addCounts(const SoloReadBarcode &rfIn)
@@ -31,6 +30,9 @@ void SoloReadBarcode::addCounts(const SoloReadBarcode &rfIn)
             cbReadCountExact[ii] += rfIn.cbReadCountExact[ii];
         };
     };
+        
+    for (uint32 ii=0; ii<qualHist.size(); ii++)
+        qualHist[ii] += rfIn.qualHist[ii];
 };
 
 void SoloReadBarcode::addStats(const SoloReadBarcode &rfIn)
