@@ -3,6 +3,8 @@
 #include "SequenceFuns.h"
 #include "ErrorWarning.h"
 #include "GlobalVariables.h"
+#include <chrono>
+#include <thread>
 
 void SoloReadBarcode::matchCBtoWL(string &cbSeq1, string &cbQual1, vector<uint64> &cbWL, int32 &cbMatch1, vector<uint64> &cbMatchInd1, string &cbMatchString1)
 {
@@ -178,6 +180,7 @@ void SoloReadBarcode::getCBandUMI(char **readSeq, char **readQual, uint64 *readL
         };
         
         bSeq = {};
+        bStrings.clear();
         for (auto &tag: pSolo.samAtrrBarcodeSeq) {
             size_t pos1 = readNameExtraT.find(tag); //find tag
             if ( pos1 == std::string::npos ) {
@@ -189,7 +192,9 @@ void SoloReadBarcode::getCBandUMI(char **readSeq, char **readQual, uint64 *readL
             };
             pos1 +=6; //skip 6 chars, e.g. \tCB:Z:
             size_t pos2 = readNameExtraT.find('\t', pos1); //find next \t
-            bSeq += readNameExtraT.substr(pos1,pos2-pos1);
+            bStrings.push_back(readNameExtraT.substr(pos1,pos2-pos1));
+            bSeq += bStrings.back();
+            
         };
 
         bQual = {};        
@@ -245,19 +250,49 @@ void SoloReadBarcode::getCBandUMI(char **readSeq, char **readQual, uint64 *readL
     ////////////////// cbSeq and umiSeq, and match CB to WL, different CB_UMI types
     ///////////////////////////CB_UMI_Simple a.k.a Droplet
     if ( pSolo.type==pSolo.SoloTypes::CB_UMI_Simple ) {
-        cbSeq=bSeq.substr(pSolo.cbS-1,pSolo.cbL);
-        umiSeq=bSeq.substr(pSolo.umiS-1,pSolo.umiL);
-        cbQual=bQual.substr(pSolo.cbS-1,pSolo.cbL);
-        umiQual=bQual.substr(pSolo.umiS-1,pSolo.umiL);
-        
-        for (uint64 ix=0; ix<cbQual.size(); ix++) {
-            qualHist[(uint8)cbQual[ix]]++;
+
+        if (pSolo.CBtype.type==1) {//sequence cb
+            cbSeq=bSeq.substr(pSolo.cbS-1,pSolo.cbL);
+            umiSeq=bSeq.substr(pSolo.umiS-1,pSolo.umiL);
+            cbQual=bQual.substr(pSolo.cbS-1,pSolo.cbL);
+            umiQual=bQual.substr(pSolo.umiS-1,pSolo.umiL);
+
+
+            for (uint64 ix=0; ix<cbQual.size(); ix++) {
+                qualHist[(uint8)cbQual[ix]]++;
+            };
+            for (uint64 ix=0; ix<umiQual.size(); ix++) {
+                qualHist[(uint8)umiQual[ix]]++;
+            };               
+            
+            matchCBtoWL(cbSeq, cbQual, pSolo.cbWL, cbMatch, cbMatchInd, cbMatchString);
+        } else if (pSolo.CBtype.type==2) {//string cb
+            /* this seg-faults
+            while (pSolo.CBtype.strMap.count(cbSeq)==0) {
+                if (pSolo.CBtype.strMtx->try_lock()) {
+                    pSolo.CBtype.strMap[cbSeq] = pSolo.CBtype.strMap.size();
+                    pSolo.CBtype.strMtx->unlock();
+                };
+                    //std::this_thread::sleep_for(std::chrono::nanoseconds(10));
+            };
+            */
+            cbSeq = bStrings[0];
+            umiSeq = bStrings[1];
+            pSolo.CBtype.strMtx->lock();
+            auto cbi = pSolo.CBtype.strMap.find(cbSeq);
+            uint32 cb1;
+            if (cbi == pSolo.CBtype.strMap.end()) {
+                cb1 = pSolo.CBtype.strMap.size();
+                pSolo.CBtype.strMap[cbSeq] = cb1;
+            } else {
+                cb1 = cbi->second;
+            };
+            pSolo.CBtype.strMtx->unlock();
+            
+            cbMatchInd.push_back(cb1);//all possible barcodes are accepted. This will overflow if CB is longer than 31b
+            cbMatchString = std::to_string(cb1);
+            cbMatch=0;
         };
-        for (uint64 ix=0; ix<umiQual.size(); ix++) {
-            qualHist[(uint8)umiQual[ix]]++;
-        };
-             
-        matchCBtoWL(cbSeq, cbQual, pSolo.cbWL, cbMatch, cbMatchInd, cbMatchString);
 
         if (!convertCheckUMI()) {//UMI conversion
             #ifdef MATCH_CellRanger
@@ -315,6 +350,9 @@ void SoloReadBarcode::getCBandUMI(char **readSeq, char **readQual, uint64 *readL
             return;
         };
 
+        if ( pSolo.umiL == 0 )
+            pSolo.umiL = umiSeq.size();
+
         bool cbMatchGood=true;
         if (!convertCheckUMI()) {
             cbMatchGood = false;//CB matching will not be done, just extract the sequences
