@@ -7,6 +7,9 @@ void SoloRead::record(uint64 nTr, Transcript **alignOut, uint64 iRead, ReadAnnot
     if (pSolo.type==pSolo.SoloTypes::CB_samTagOut)
         return;
 
+    if (pSolo.readStats.yes)
+        readFlagReset();
+
     for (uint32 ii=0; ii<pSolo.nFeatures; ii++)
         readFeat[ii]->record(*readBar, nTr, alignOut, iRead, readAnnot);
 };
