@@ -176,11 +176,17 @@ int alignToTranscriptMinOverlap(Transcript &aG, uint trS1, uint32 *exSE1, uint16
 
 void Transcriptome::classifyAlign (Transcript **alignG, uint64 nAlignG, ReadAnnotations &readAnnot) 
 {
-    readAnnot.transcriptConcordant={};
-    readAnnot.geneConcordant={};
-    readAnnot.trVelocytoType={};
-            
+    // readAnnot.transcriptConcordant={};
+    // readAnnot.trVelocytoType={};
     //array<bool,AlignVsTranscript::N> reAnn={false};
+
+
+    ReadAnnotFeature &annFeat = readAnnot.annotFeatures[SoloFeatureTypes::Gene];
+    // annFeat.fSet={};
+    // annFeat.fAlign = {};       
+    // annFeat.ovType = 0;
+
+    annFeat.fAlign.resize(nAlignG);    
     uint32 reGe=(uint32)-2;//so that the first gene can be recorded
     std::bitset<velocytoTypeGeneBits> reAnn; //initialized to 0 (false)
        
@@ -214,9 +220,8 @@ void Transcriptome::classifyAlign (Transcript **alignG, uint64 nAlignG, ReadAnno
                 uint64 distTTS = (uint64) ( trStr[tr1]==1 ? distTrEnds[1] : distTrEnds[0] );
                 readAnnot.transcriptConcordant.push_back({tr1,(uint32) distTTS});
 
-                readAnnot.geneConcordant.insert(trGene[tr1]);//genes for all alignments
-                readAnnot.geneConcordantTr=iag;
-                aG.alignGenes.insert(trGene[tr1]);//genes for each alignment
+                annFeat.fSet.insert(trGene[tr1]);//genes for all alignments
+                annFeat.fAlign[iag].insert(trGene[tr1]);
             };
             
             if ((P.pSolo.featureYes[SoloFeatureTypes::Velocyto] || P.pSolo.featureYes[SoloFeatureTypes::VelocytoSimple]) && nAlignG==1) {//another calculation for velocyto with minOverlapMinusOne=6
@@ -254,6 +259,8 @@ void Transcriptome::classifyAlign (Transcript **alignG, uint64 nAlignG, ReadAnno
         } while (trEmax[tr1]>=aGend && tr1>0);
     };
     
+    if ( annFeat.fSet.size()>0 )
+        annFeat.ovType = ReadAnnotFeature::overlapTypes::exonic;
     //VelocytoSimple logic
     readAnnot.geneVelocytoSimple[0]=(reGe+2==0 ? (uint32)-1 : reGe);//-2 marks no gene, convert to -1 which marks either no gene or multigene - no output     
     readAnnot.geneVelocytoSimple[1]=reAnn.to_ulong();
